@@ -2,7 +2,7 @@
  *			GPAC - Multimedia Framework C SDK
  *
  *			Authors: Jean Le Feuvre, Cyril Concolato, Romain Bouqueau
- *			Copyright (c) Telecom ParisTech 2006-2019
+ *			Copyright (c) Telecom ParisTech 2006-2022
  *
  *  This file is part of GPAC / MPEG2-TS sub-project
  *
@@ -288,7 +288,8 @@ typedef enum
 	GF_M2TS_MPE_SECTIONS            = 0x90,
 	GF_M2TS_SUBTITLE_DVB			= 0x100,
 	GF_M2TS_AUDIO_OPUS				= 0x101,
-	
+	GF_M2TS_VIDEO_AV1				= 0x102,
+
 	GF_M2TS_DVB_TELETEXT			= 0x152,
 	GF_M2TS_DVB_VBI					= 0x153,
 	GF_M2TS_DVB_SUBTITLE			= 0x154,
@@ -309,7 +310,7 @@ enum
 	GF_M2TS_RA_STREAM_DTS3	= GF_4CC('D','T','S','3'),
 	GF_M2TS_RA_STREAM_OPUS	= GF_4CC('O','p','u','s'),
 	GF_M2TS_RA_STREAM_DOVI	= GF_4CC('D','O','V','I'),
-
+	GF_M2TS_RA_STREAM_AV1	= GF_4CC('A','V','0','1'),
 
 	GF_M2TS_RA_STREAM_GPAC	= GF_4CC('G','P','A','C')
 };
@@ -709,8 +710,10 @@ enum
 	GF_M2TS_FAKE_PCR = 1<<7,
 	/*! signals the stream type is a gpac codec id*/
 	GF_M2TS_GPAC_CODEC_ID = 1<<8,
-	/*! signals the stream type is a gpac codec id*/
+	/*! signals the stream is a PMT*/
 	GF_M2TS_ES_IS_PMT = 1<<9,
+	/*! signals the stream is reused (fake pcr streams), i.e. present twice in ess[] list*/
+	GF_M2TS_ES_IS_PCR_REUSE = 1<<10,
 
 	/*! all flags above this mask are used by demultiplexer users*/
 	GF_M2TS_ES_STATIC_FLAGS_MASK = 0x0000FFFF,
@@ -722,7 +725,13 @@ enum
 	/*! flag used by importers/readers to mark streams that have been seen already in PMT process (update/found)*/
 	GF_M2TS_ES_ALREADY_DECLARED = 1<<18,
 	/*! flag indicates TEMI info is declared on this stream*/
-	GF_M2TS_ES_TEMI_INFO = 1<<19
+	GF_M2TS_ES_TEMI_INFO = 1<<19,
+	/*! flag indicates each PES is a full AU*/
+	GF_M2TS_ES_FULL_AU = 1<<20,
+	/*! flag indicates ES is not sparse (AV), used to check discontinuity - set by user*/
+	GF_M2TS_CHECK_DISC = 1<<21,
+	/*! flag indicates VC1 sequence header is to be checked - set by user*/
+	GF_M2TS_CHECK_VC1 = 1<<22,
 };
 
 /*! macro for abstract Section/PES stream object, only used for type casting*/
@@ -881,6 +890,10 @@ typedef struct tag_m2ts_pes
 	Bool is_resume;
 	/*! DolbiVison info, last byte set to 1 if non-compatible signaling*/
 	u8 dv_info[25];
+
+	u64 map_utc, map_utc_pcr, map_pcr;
+	u8 *gpac_meta_dsi;
+	u32 gpac_meta_dsi_size;
 } GF_M2TS_PES;
 
 /*! reserved streamID for PES headers*/
@@ -925,11 +938,17 @@ typedef struct
 /*! TDT/TOT (Time and Date table) information*/
 typedef struct
 {
+	/*! year*/
 	u16 year;
+	/*! month, from 0 to 11*/
 	u8 month;
+	/*! day, from 1 to 31*/
 	u8 day;
+	/*! hour*/
 	u8 hour;
+	/*! minute*/
 	u8 minute;
+	/*! second*/
 	u8 second;
 } GF_M2TS_TDT_TOT;
 
@@ -1391,12 +1410,14 @@ enum
 	GF_ESI_STREAM_WITHOUT_MPEG4_SYSTEMS =	1<<3,
 	/*! stream is not signaled through MPEG-4 Systems (OD stream) */
 	GF_ESI_AAC_USE_LATM =	1<<4,
-	/*! temporrary end of stream (flush of segment)*/
+	/*! temporary end of stream (flush of segment)*/
 	GF_ESI_STREAM_FLUSH	=	1<<5,
 	/*! stream uses HLS SAES encryption*/
 	GF_ESI_STREAM_HLS_SAES	=	1<<6,
 	/*! stream uses non-backward DolbyVision signaling*/
 	GF_ESI_FORCE_DOLBY_VISION = 1<<7,
+	/*! sparse stream with currently no packets*/
+	GF_ESI_STREAM_SPARSE = 1<<8,
 };
 
 /*! elementary stream information*/
@@ -1443,7 +1464,14 @@ typedef struct __elementary_stream_ifce
 	/*! dv info, not valid if first byte not 1*/
 	u8 dv_info[24];
 
+	/*! registration authority code to use, 0 if not applicable*/
 	u32 ra_code;
+	/*! GPAC unmapped meta codec decoder config size*/
+	u32 gpac_meta_dsi_size;
+	/*! GPAC unmapped meta codec decoder config*/
+	u8 *gpac_meta_dsi;
+	/*! GPAC unmapped meta codec name if knwon*/
+	const char *gpac_meta_name;
 } GF_ESInterface;
 
 /*! @} */
